<?php

if (!defined('_PS_VERSION_')) {
    exit;
}

/**
 * @since 1.5.0
 */
class Octo_PaymentNotifyModuleFrontController extends ModuleFrontController
{
    const COMMON_API_URL = 'https://secure.octo.uz/prepare_payment';

    private function response($data)
    {
        if (!headers_sent()) {
            header('Content-Type: application/json; charset=UTF-8');
        }

        echo json_encode($data);
        die();
    }
    /**
     * @see FrontController::postProcess()
     */
    public function postProcess()
    {
        $content = file_get_contents('php://input');
        $data = json_decode($content, TRUE);

        if (json_last_error() !== JSON_ERROR_NONE) { // handle Parse error
            $this->response(['status' => 'error', 'message' => 'incorrect input json']);
        }
        $shopId = Configuration::get(Rbkmoney_Payment::OCTO_SHOP_ID);
        $key = Configuration::get(Rbkmoney_Payment::OCTO_API_KEY);

        $data = [
            'octo_shop_id' => $shopId,
            'octo_secret' => $key,
            'shop_transaction_id' => $data['shop_transaction_id'],
            'octo_payment_UUID' => $data['octo_payment_UUID'],
        ];

        $jsonData = json_encode($data);

        $ch = curl_init(self::COMMON_API_URL);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');
        curl_setopt($ch, CURLOPT_POSTFIELDS, $jsonData);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Content-Type: application/json',
            'Content-Length: ' . strlen($jsonData),
        ));

        $result = json_decode(curl_exec($ch), true);
        $httpcode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);

        $orderId = Order::getOrderByCartId($result['shop_transaction_id']);
        $order = new Order($orderId);

        if ($httpcode === 200) {

            if ($result['status'] === 'waiting_for_capture') {
                $order->setCurrentState(Configuration::get('PS_OS_WS_PAYMENT'));

                return $this->response(['accept_status' => 'capture']);
            } else if ($result['status'] === 'succeeded') {
                $order->setCurrentState(Configuration::get('PS_OS_WS_PAYMENT'));

                return $this->response(['accept_status' => 'completed']);
            } else if ($result['status'] === 'canceled') {
                $order->setCurrentState(Configuration::get('_PS_OS_CANCELED_'));

                return $this->response(['accept_status' => 'canceled']);
            }

            return $this->response(['status' => 'error', 'message' => 'UNSUPPORTED OCTO STATUS']);
        }

        return $this->response(['status' => 'error', 'message' => 'COULD NOT CHECK BACK']);
    }

}
