<?php

if (!defined('_PS_VERSION_')) {
    exit;
}


/**
 * @since 1.5.0
 */
class Octo_PaymentPaymentModuleFrontController extends ModuleFrontController
{

    const COMMON_API_URL = 'https://secure.octo.uz/prepare_payment';



    /**
     * @see FrontController::initContent()
     */
    public function initContent()
    {
        parent::initContent();
        global $currency;
        $cart = $this->context->cart;
        $shopId = Configuration::get(Octo_Payment::OCTO_SHOP_ID);
        $key = Configuration::get(Octo_Payment::OCTO_API_KEY);
        $is_test = Configuration::get(Octo_Payment::OCTO_TEST);
        $totalAmount = $this->getTotalAmount($cart);
        $currency = $this->context->currency;
        $successUrl = 'http://' . htmlspecialchars($_SERVER['HTTP_HOST'], ENT_COMPAT, 'UTF-8')
            . __PS_BASE_URI__ . 'index.php?fc=module&module=' . $this->module->name . '&controller=success';

        $data = [
            'test' => (bool)($is_test === 'true'),
            'octo_shop_id' => $shopId,
            'octo_secret' => $key,
            'shop_transaction_id' => $cart->id,
            'auto_capture' => false,
            'init_time' => date('Y-m-d H:i:s'),
            'total_sum' => $totalAmount,
            'currency' => $currency->iso_code,
            "payment_methods" => [
                [
                    "method" => "uzcard"
                ],
                [
                    "method" => "humo"
                ],
                [
                    "method" => "bank_card"
                ]
            ],
            'description' => 'ORDER №'.$cart->id,
            'return_url' => $successUrl
        ];


        $jsonData = json_encode($data);

        $ch = curl_init(self::COMMON_API_URL);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');
        curl_setopt($ch, CURLOPT_POSTFIELDS, $jsonData);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Content-Type: application/json',
            'Content-Length: ' . strlen($jsonData),
        ));

        $body = curl_exec($ch);
        $httpcode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);

        if ($httpcode === 200) {
            $data = json_decode($body, true);

            $customer = new Customer($cart->id_customer);

            $rbkmoney = new Octo_Payment();
            $rbkmoney->validateOrder((int)$cart->id,
                Configuration::get('PS_OS_BANKWIRE'), $cart->getOrderTotal(),
                $this->module->displayName, null, null,
                $cart->id_currency, false,
                $customer->secure_key);

            if ($data['error'] !== 0) {
                return '<p>OCTO.uz ERROR: ' . $data['errorMessage'] . '</p>';
            }else{
                Tools::redirect($data['octo_pay_url']);
            }
        }
    }
    /**
     * Get total amount
     * @param Cart $cart
     * @return float|int
     */
    function getTotalAmount(Cart $cart)
    {
        $amount = 0;
        foreach ($cart->getProducts() as $product) {
            $totalPrice = $product['quantity'] * round($product['price_wt'], 2, PHP_ROUND_HALF_UP);
            $price = round($totalPrice, 2, PHP_ROUND_HALF_UP);
            $amount += $price;
        }

        // Добавляем доставку
        /** @var Carrier $carrier */
        $carrier = $cart->getSummaryDetails()['carrier'];
        if (!$carrier->is_free && $cart->getPackageShippingCost() > 0) {
            $amount += $cart->getPackageShippingCost();
        }
        return $amount;
    }

}
