<?php

use PrestaShop\PrestaShop\Core\Payment\PaymentOption;

if (!defined('_PS_VERSION_')) {
    exit;
}


/**
 * Class RbkmoneyPayment
 *
 * @see https://rbkmoney.github.io/docs/
 * @see https://rbkmoney.github.io/api/
 * @see https://rbkmoney.github.io/webhooks-events-api/
 * @see http://doc.prestashop.com/display/PS17/User+Guide
 * @see http://doc.prestashop.com/display/PS17/Payment+Preferences
 * @see http://developers.prestashop.com/module/50-PaymentModules/index.html
 */
class Octo_Payment extends PaymentModule
{

    // Required
    const OCTO_SHOP_ID = 'OCTO_SHOP_ID';
    const OCTO_SHOP_ID_DEFAULT = '0';
    const OCTO_API_KEY = 'OCTO_API_KEY';
    const OCTO_TEST = 'OCTO_TEST';

    const OCTO_TEST_TRUE = 'true';
    const OCTO_TEST_FALSE = 'false';

    // Other
    const CHARSET = 'UTF-8';


    /**
     * rbkmoney_payment constructor.
     */
    function __construct()
    {
        $this->name = 'octo_payment';
        $this->tab = 'payments_gateways';
        $this->version = '1.0.0';
        $this->author = 'OCTO';
        $this->need_instance = 1;
        $this->ps_versions_compliancy = array('min' => '1.7', 'max' => _PS_VERSION_);
        $this->controllers = array('payment', 'success', 'notify');
        $this->currencies = true;
        $this->currencies_mode = 'radio';

        parent::__construct();

        $this->displayName = $this->l('Платежная система Octo');
        $this->description = $this->l('Прием платежей через платежную систему Octo');
        $this->confirmUninstall = $this->l('Вы действительно хотите удалить?');
    }

    /**
     * @return bool
     */
    function install()
    {

        if (Shop::isFeatureActive()) {
            Shop::setContext(Shop::CONTEXT_ALL);
        }

        parent::install();

        // Registration hook
        $this->registerHook('paymentReturn');
        $this->registerHook('paymentOptions');

        if (!Configuration::updateValue(static::OCTO_SHOP_ID, static::OCTO_SHOP_ID_DEFAULT)
            || !Configuration::updateValue(static::OCTO_API_KEY, '')
            || !Configuration::updateValue(static::OCTO_TEST, static::OCTO_TEST_TRUE)
        ) {
            return false;
        }

        return true;
    }

    /**
     * @return bool
     */
    function uninstall()
    {
        $config = array(
            static::OCTO_SHOP_ID,
            static::OCTO_API_KEY,
            static::OCTO_TEST,

        );

        foreach ($config as $name) {
            Configuration::deleteByName($name);
        }

        // Uninstall default
        parent::uninstall();

        return true;
    }

    /**
     * @return string
     */
    public function getContent()
    {
        $this->output = "<h2>OCTO</h2>";

        if (isset($_POST['submit'])) {

            $params = [
                'octo_shop_id' => static::OCTO_SHOP_ID,
                'octo_api_key' => static::OCTO_API_KEY,
                'octo_test' => static::OCTO_TEST,

            ];

            foreach ($params as $key => $value) {
                if(!$_POST['octo_test']) Configuration::updateValue(static::OCTO_TEST, 'true');
                if (!empty($_POST[$key])) {
                    Configuration::updateValue($value, $_POST[$key]);
                }
            }

            $this->output .= '<div class="conf confirm"><img src="../img/admin/enabled.gif" alt="' . $this->l('Подтверждение') . '" />' . $this->l('Настройки обновлены') . '</div>';
        }

        $this->displayFormSettings();

        return $this->output;
    }

    /**
     * Settings
     */
    public function displayFormSettings()
    {
        $octo_shop_id = htmlentities(Configuration::get(static::OCTO_SHOP_ID), ENT_COMPAT, static::CHARSET);
        $octo_api_key = htmlentities(Configuration::get(static::OCTO_API_KEY), ENT_COMPAT, static::CHARSET);
        $octo_test = htmlentities(Configuration::get(static::OCTO_TEST), ENT_COMPAT, static::CHARSET);
        $successUrl = 'http://' . htmlspecialchars($_SERVER['HTTP_HOST'], ENT_COMPAT, 'UTF-8')
            . __PS_BASE_URI__ . 'index.php?fc=module&module=octo_payment&controller=notify';

        $cheked = 'checked="checked"';
        $value = 'false';
        if (htmlentities(Configuration::get(static::OCTO_TEST), ENT_COMPAT, static::CHARSET) == 'true') {
            $cheked = '';
            $value = 'false';
        }

        $this->output .= '<form action="' . $_SERVER['REQUEST_URI'] . '" method="post" xmlns="http://www.w3.org/1999/html">
		    <fieldset>
			    <legend><img src="../img/admin/contact.gif" />' . $this->l('Настройки платежного модуля OCTO') . '</legend>
			    <h3>' . $this->l('Обязательные настройки') . '</h3>
			    <label for="octo_test">' .$this->l('URL Уведомлений для OCTO.uz:') . '</label>
			    <div class="margin-form">
			        <h2 style="margin: 0;">'.$successUrl.'</h2>
			    </div>
			    <label for="octo_test">' . $this->l('Реальные платежи') . '</label>
			    <div class="margin-form">
			        <input type="checkbox" name="octo_test" id="octo_test" size="121px" value="' . $value . '" '.$cheked.'/>
			    </div>
			    <label for="octo_shop_id">' . $this->l('ID магазина') . '</label>
			    <div class="margin-form">
			        <input type="text" name="octo_shop_id" id="octo_shop_id" size="121px" value="' . $octo_shop_id . '" />
			    </div>
			    
			    <label for="octo_api_key">' . $this->l('Ваш ключ для доступа к API из') .' <a target="_blank" href="https://merchant.octo.uz/">merchant.octo.uz</a>' . '</label>
			    <div class="margin-form">
			        <input type="text" name="octo_api_key" size="121px" value="'.$octo_api_key.'">
			    </div>
			    
			    <h3>' . $this->l('Документация') . '</h3>
			    <ul>
			        <li><a href="https://help.octo.uz/" target="_blank">' . $this->l('Документация по интеграции') .'</a></li>
                </ul>

                <div class="margin-form">
                    <input type="submit" name="submit" value="' . $this->l('Обновить настройки') . '" class="button" />
                </div>
		    </fieldset>
		</form>';

    }

    /**
     * Отображение в корзине при выборе способа оплаты
     * @param $params
     * @return array|void
     */
    public function hookPaymentOptions($params)
    {
        $payments_options = [];

        if (!$this->active) {
            return $payments_options;
        }

        $payment_options = new PaymentOption();
        $payment_options->setAction($this->context->link->getModuleLink($this->name, 'payment', array(), true));
        $payment_options->setCallToActionText("OCTO");
        $payment_options->setModuleName($this->name);
        $payment_options->setAdditionalInformation($this->fetch('module:octo_payment/views/templates/front/payment_infos.tpl'));

        $payments_options[] = $payment_options;
        return $payments_options;
    }

    /**
     * @param $params
     * @return string
     */
    function hookPaymentReturn($params)
    {
        return $this->display(__FILE__, 'module:octo_payment/views/templates/front/payment_success.tpl');
    }

    /**
     * @param int $id_cart
     * @param int $id_order_state
     * @param float $amount_paid
     * @param string $payment_method
     * @param null $message
     * @param array $extra_vars
     * @param null $currency_special
     * @param bool $dont_touch_amount
     * @param bool $secure_key
     * @param Shop|null $shop
     *
     * @return boolean
     */
    public function validateOrder(
        $id_cart,
        $id_order_state,
        $amount_paid,
        $payment_method = 'Unknown',
        $message = null,
        $extra_vars = array(),
        $currency_special = null,
        $dont_touch_amount = false,
        $secure_key = false,
        Shop $shop = null
    )
    {
        parent::validateOrder($id_cart, $id_order_state, $amount_paid,
            $payment_method, $message, $extra_vars, $currency_special,
            $dont_touch_amount, $secure_key, $shop);
    }


}